Take control of your home grid.

You can
===========

 * run applications across multiple computers and platforms transparently, just as you would from your terminal. The application will run on the most appropriate node, determined by algorithm.
 * run tasks (run code fragments or processes) transparently across the system. The tasks can be either automatically assigned to a node, similar as the applications; or the can be assigned explicitly to a node.

Requirements
============

 * psutil
 * ws4py 
